CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
90 lines
2.7 KiB
C++
90 lines
2.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip/hip_runtime_api.h>
|
|
#include <hip/hip_gl_interop.h>
|
|
|
|
#include "gl_interop_common.hh"
|
|
|
|
namespace {
|
|
constexpr std::array<hipGLDeviceList, 3> kDeviceLists{
|
|
hipGLDeviceListAll, hipGLDeviceListCurrentFrame, hipGLDeviceListNextFrame};
|
|
} // anonymous namespace
|
|
|
|
HIP_TEST_CASE(Unit_hipGLGetDevices_Positive_Basic) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
GLContextScopeGuard gl_context;
|
|
|
|
const auto device_list = GENERATE(from_range(begin(kDeviceLists), end(kDeviceLists)));
|
|
|
|
const int device_count = HipTest::getDeviceCount();
|
|
|
|
unsigned int gl_device_count = 0;
|
|
std::vector<int> gl_devices(device_count, -1);
|
|
|
|
if (device_list == hipGLDeviceListNextFrame) {
|
|
HIP_CHECK_ERROR(hipGLGetDevices(&gl_device_count, gl_devices.data(), device_count, device_list),
|
|
hipErrorNotSupported);
|
|
REQUIRE(gl_device_count == 0);
|
|
REQUIRE(gl_devices.at(0) == -1);
|
|
} else {
|
|
HIP_CHECK(hipGLGetDevices(&gl_device_count, gl_devices.data(), device_count, device_list));
|
|
REQUIRE(gl_device_count == 1);
|
|
REQUIRE(gl_devices.at(0) == 0);
|
|
}
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipGLGetDevices_Positive_Parameters) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
GLContextScopeGuard gl_context;
|
|
|
|
const int device_count = HipTest::getDeviceCount();
|
|
|
|
unsigned int gl_device_count = 0;
|
|
std::vector<int> gl_devices(device_count, -1);
|
|
|
|
SECTION("pHipDeviceCount == nullptr") {
|
|
HIP_CHECK_ERROR(hipGLGetDevices(nullptr, gl_devices.data(), device_count, hipGLDeviceListAll),
|
|
hipErrorInvalidValue);
|
|
REQUIRE(gl_devices.at(0) == -1);
|
|
}
|
|
|
|
SECTION("pHipDevices == nullptr") {
|
|
HIP_CHECK_ERROR(hipGLGetDevices(&gl_device_count, nullptr, device_count, hipGLDeviceListAll),
|
|
hipErrorInvalidValue);
|
|
REQUIRE(gl_device_count == 0);
|
|
}
|
|
|
|
SECTION("hipDeviceCount == 0") {
|
|
HIP_CHECK_ERROR(hipGLGetDevices(&gl_device_count, gl_devices.data(), 0, hipGLDeviceListAll),
|
|
hipErrorInvalidValue);
|
|
REQUIRE(gl_device_count == 0);
|
|
REQUIRE(gl_devices.at(0) == -1);
|
|
}
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipGLGetDevices_Negative_Parameters) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
GLContextScopeGuard gl_context;
|
|
|
|
const int device_count = HipTest::getDeviceCount();
|
|
|
|
unsigned int gl_device_count = 0;
|
|
std::vector<int> gl_devices(device_count, -1);
|
|
|
|
SECTION("invalid deviceList") {
|
|
HIP_CHECK_ERROR(hipGLGetDevices(&gl_device_count, gl_devices.data(), device_count,
|
|
static_cast<hipGLDeviceList>(-1)),
|
|
hipErrorInvalidValue);
|
|
REQUIRE(gl_device_count == 0);
|
|
REQUIRE(gl_devices.at(0) == -1);
|
|
}
|
|
}
|